Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon SQS.

Actions, resources, and condition keys for Amazon SQS - Service Authorization Reference

# Actions, resources, and condition keys for Amazon SQS

Amazon SQS (service prefix: `sqs` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon SQS
- Resource types defined by Amazon SQS
- Condition keys for Amazon SQS

## Actions defined by Amazon SQS

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddPermission | Grants permission to a queue for a specific principal | Permissions management | queue* |  |
ChangeMessageVisibility | Grants permission to change the visibility timeout of a specified message in a queue to a new value | Write | queue* |  |
CreateQueue | Grants permission to create a new queue, or returns the URL of an existing one | Write | queue* |  |
DeleteMessage | Grants permission to delete the specified message from the specified queue | Write | queue* |  |
DeleteQueue | Grants permission to delete the queue specified by the queue URL, regardless of whether the queue is empty | Write | queue* |  |
GetQueueAttributes | Grants permission to get attributes for the specified queue | Read | queue* |  |
GetQueueUrl | Grants permission to return the URL of an existing queue | Read | queue* |  |
ListDeadLetterSourceQueues | Grants permission to return a list of your queues that have the RedrivePolicy queue attribute configured with a dead letter queue | Read | queue* |  |
ListQueueTags | Grants permission to list tags added to an SQS queue | Read | queue* |  |
ListQueues | Grants permission to return a list of your queues | Read |  |  |
PurgeQueue | Grants permission to delete the messages in a queue specified by the queue URL | Write | queue* |  |
ReceiveMessage | Grants permission to retrieve one or more messages, with a maximum limit of 10 messages, from the specified queue | Read | queue* |  |
RemovePermission | Grants permission to revoke any permissions in the queue policy that matches the specified Label parameter | Permissions management | queue* |  |
SendMessage | Grants permission to deliver a message to the specified queue | Write | queue* |  |
SetQueueAttributes | Grants permission to set the value of one or more queue attributes | Write | queue* |  |
TagQueue | Grants permission to add tags to the specified SQS queue | Tagging | queue* |  |
UntagQueue | Grants permission to remove tags from the specified SQS queue | Tagging | queue* |  |

## Resource types defined by Amazon SQS

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Note

The ARN of the queue is used only in IAM permission policies. In API and CLI calls, you use the queue's URL instead.

Resource types | ARN | Condition keys
--- | --- | ---
queue | `arn:$ { Partition}:sqs:$ { Region}:$ { Account}:$ { QueueName}` |

## Condition keys for Amazon SQS

SQS has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.